import java.io.IOException;

import org.eclipse.birt.report.engine.api.EngineConfig;
import org.eclipse.birt.report.model.api.CellHandle;
import org.eclipse.birt.report.model.api.DesignElementHandle;
import org.eclipse.birt.report.model.api.DesignEngine;
import org.eclipse.birt.report.model.api.ElementFactory;
import org.eclipse.birt.report.model.api.GridHandle;
import org.eclipse.birt.report.model.api.ImageHandle;
import org.eclipse.birt.report.model.api.LabelHandle;
import org.eclipse.birt.report.model.api.ReportDesignHandle;
import org.eclipse.birt.report.model.api.RowHandle;
import org.eclipse.birt.report.model.api.SessionHandle;
import org.eclipse.birt.report.model.api.TableHandle;
import org.eclipse.birt.report.model.api.activity.SemanticException;

public class CreateReport{
	
	static void createReport() throws IOException, SemanticException {
		//Engine Configuration - set and get temp dir, BIRT home, Servlet context
		EngineConfig config = new EngineConfig();
		config.setEngineHome(ExampleConstants.BIRT_HOME);
		System.out.println(ExampleConstants.CREATE + "rptdesign");
		System.out.println(ExampleConstants.EXAMPLE_HOME);

		// Create a session handle.  Use Default Locale
		SessionHandle session = DesignEngine.newSession(null);
		// Create a new report design.
		ReportDesignHandle design = session.createDesign();
		// The element factory creates instances of the various BIRT elements.
		ElementFactory factory = design.getElementFactory();
		// Create a simple master page
		DesignElementHandle element = factory.newSimpleMasterPage("Page Master");
		design.getMasterPages().add(element);

		// Create a grid and add it to the "body" slot of the report design.
		GridHandle grid = factory.newGridItem(null, 1 /* cols */, 3 /* row */);
		grid.setWidth("100%");
		design.getBody().add(grid);

		// Create an image and add it to the first cell.
		ImageHandle image = factory.newImage(null);
		image.setURI(ExampleConstants.LOGO);
		// get a handle to the first row
		RowHandle row = (RowHandle) grid.getRows().get(0);
		CellHandle cell = (CellHandle) row.getCells().get(0);
		cell.getContent().add(image);

		// Create a Label and add to the grid
		LabelHandle label = factory.newLabel(null);
		label.setText("BIRT Loves Europe!");
		label.setProperty("fontSize","x-large");
		label.setProperty("fontWeight","bold");
		label.setProperty("fontStyle","italic");
		label.setProperty("textAlign","center");
		label.setProperty("backgroundColor","#000000");
		label.setProperty("color","#FFFFFF");
		RowHandle row2 = (RowHandle) grid.getRows().get(1);
		CellHandle cell2 = (CellHandle) row2.getCells().get(0);
		cell2.getContent().add(label);

		// Add a table to the grid
		TableHandle tableHandle = factory.newTableItem("test", 3);
		tableHandle.setWidth("100%");
		RowHandle row3 = (RowHandle) grid.getRows().get(2);
		CellHandle cell3 = (CellHandle) row3.getCells().get(0);
		cell3.getContent().add(tableHandle);

		// Save the design and close it.
		design.saveAs(ExampleConstants.CREATE + "rptdesign");
		design.close();
		session.closeAll(true);
		System.out.println("Finished!");

	}

	public static void main(String[] args) {
		try {
			createReport();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
